Информационные команды — СпамоБорец: документация

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- API СпамоБорца »

# Информационные команды

## Команда sf.info.version

Получить версию сервера.

### Авторизация

Не требуется.

### Параметры

Нет.

### Результат

`version`
  string версия сервера

### Пример

#### XML-RPC

    <?xml version="1.0" encoding="UTF-8"?>
    <methodCall>
      <methodName>sf.info.version</methodName>
      <params>
        <param>
          <value>
            <struct/>
          </value>
        </param>
      </params>
    </methodCall>

    <?xml version="1.0"?>
    <methodResponse>
      <params>
        <param>
          <value>
            <struct>
              <member>
                <name>version</name>
                <value>
                  <string>0.1</string>
                </value>
              </member>
            </struct>
          </value>
        </param>
      </params>
    </methodResponse>

#### JSON-RPC

    {"service":null,"method":"sf.info.version","id":1,"params":[{}]}

    {"result": {"version": "0.1"}, "id": 1}

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- API СпамоБорца »